@@ -1,11 +1,18 @@
 import sys
 import os
 import shutil
-
-from serverD.conf import *
+from subprocess import Popen, PIPE
 
 file_path = os.path.abspath(os.path.dirname(__file__))
 
+if os.path.exists("{}/conf.py".format(file_path)):
+
+    from serverD.conf import *
+else:
+    from serverD.conf_demo import *
+
+    shutil.copy("{}/conf_demo.py".format(file_path), "{}/conf.py".format(file_path))
+
 server_base_data = {
 
     "serverPut": "{user} {host} {pwd} {port} {locPath} {serPath}",
@@ -15,6 +22,7 @@ server_base_data = {
 
 }
 
+
 class ServerD:
 
     @staticmethod
@@ -34,7 +42,7 @@ class ServerD:
         s_data = server_base_data.get(s_type).format(**login_dict)
         self.serverB(s_type, s_data)
 
-    def get(self, server_name, locPath, serPath):
+    def get(self, server_name, locPath, serPath, root=False):
         s_type = "serverGet"
         if not isinstance(server_name, str):
             server_name = "{}".format(server_name)
@@ -42,11 +50,14 @@ class ServerD:
         if not get_dict:
             print("{} 不存在".format(server_name))
             exit(1)
-        get_dict.update({"locPath": locPath, "serPath": serPath})
+        if root:
+            get_dict.update({"locPath": locPath, "serPath": serPath, "user": 'root', "pwd": root_pwd})
+        else:
+            get_dict.update({"locPath": locPath, "serPath": serPath})
         s_data = server_base_data.get(s_type).format(**get_dict)
         self.serverB(s_type, s_data)
 
-    def put(self, server_name, locPath, serPath):
+    def put(self, server_name, locPath, serPath, root=False):
         s_type = "serverPut"
         if not isinstance(server_name, str):
             server_name = "{}".format(server_name)
@@ -54,7 +65,10 @@ class ServerD:
         if not get_dict:
             print("{} 不存在".format(server_name))
             exit(1)
-        get_dict.update({"locPath": locPath, "serPath": serPath})
+        if root:
+            get_dict.update({"locPath": locPath, "serPath": serPath, "user": 'root', "pwd": root_pwd})
+        else:
+            get_dict.update({"locPath": locPath, "serPath": serPath})
         s_data = server_base_data.get(s_type).format(**get_dict)
         self.serverB(s_type, s_data)
 
@@ -98,21 +112,33 @@ class ServerD:
 
                 elif server == "get":
                     try:
-                        server_name = sys.argv[1]
-                        serPath = sys.argv[2]
-                        locPath = sys.argv[3]
-                        self.get(server_name, locPath, serPath)
+                        if sys.argv[1] == "root":
+                            server_name = sys.argv[2]
+                            serPath = sys.argv[3]
+                            locPath = sys.argv[4]
+                            self.get(server_name, locPath, serPath, root=True)
+                        else:
+                            server_name = sys.argv[1]
+                            serPath = sys.argv[2]
+                            locPath = sys.argv[3]
+                            self.get(server_name, locPath, serPath)
                     except IndexError:
-                        print("输入参数错误!!!\n正确示例 >>> get <服务器名称> <服务器文件路径> <本地文件路径>")
+                        print("输入参数错误!!!\n正确示例 >>> get [root] <服务器名称> <服务器文件路径> <本地文件路径>")
 
                 elif server == "put":
                     try:
-                        server_name = sys.argv[1]
-                        serPath = sys.argv[2]
-                        locPath = sys.argv[3]
-                        self.put(server_name, locPath, serPath)
+                        if sys.argv[1] == "root":
+                            server_name = sys.argv[2]
+                            serPath = sys.argv[3]
+                            locPath = sys.argv[4]
+                            self.put(server_name, locPath, serPath, root=True)
+                        else:
+                            server_name = sys.argv[1]
+                            serPath = sys.argv[2]
+                            locPath = sys.argv[3]
+                            self.put(server_name, locPath, serPath)
                     except IndexError:
-                        print("输入参数错误!!!\n正确示例 >>> put <服务器名称> <服务器文件路径> <本地文件路径>")
+                        print("输入参数错误!!!\n正确示例 >>> put [root] <服务器名称> <服务器文件路径> <本地文件路径>")
 
                 else:
                     server_name = "{}".format(server)
@@ -176,7 +202,73 @@ def update_conf():
         else:
             print("该文件不存在: {}".format(new_conf_path))
     except IndexError:
-        print("updateConf <当前配置文件路径> 可参考 {}/conf_demo.py".format(file_path))
+        print("updates <当前配置文件路径>\n 查看 可执行 vi {}/conf.py ".format(file_path))
+
+
+def open_conf():
+    """打开配置文件"""
+    p = Popen("cat {}/conf.py".format(file_path), stdout=PIPE, shell=True)
+
+    for i in p.stdout.readlines():
+        ps_str = str(i, encoding="utf-8")
+        print(ps_str, end='')
+    print()
+
+
+def alter_conf():
+    """修改配置文件"""
+    try:
+
+        if not any([user, port, pwd, root_pwd, tbj_pem]):
+            print("请录入默认配置")
+            user1 = "{}".format(input("用户名:"))  # 用户名
+            port1 = "{}".format(input("端口号:"))  # 端口号
+            pwd1 = "{}".format(input("密码:"))  # 普通密码
+            root_pwd1 = "{}".format(input("root密码:"))  # root 密码
+            tbj_pem1 = "{}".format(input("跳板机序列号:"))
+        else:
+            user1 = user  # 用户名
+            port1 = port  # 端口号
+            pwd1 = pwd  # 普通密码
+            root_pwd1 = root_pwd  # root 密码
+            tbj_pem1 = tbj_pem
+
+        if len(sys.argv) == 2:
+            conf_sname = sys.argv[1]
+            conf_param = ''
+            conf_data = ''
+        else:
+            conf_sname = sys.argv[1]
+            conf_param = sys.argv[2]
+            conf_data = sys.argv[3]
+        if conf_param == "sname":
+            server_dict[conf_data] = server_dict[conf_sname]
+            del server_dict[conf_sname]
+        elif conf_sname in server_dict and len(sys.argv) > 2:
+            server_dict[conf_sname][conf_param] = conf_data
+        else:
+
+            host = input("请录入服务器信息\n host:")
+            new_user = input("user:(若默认{}请回车键跳过)".format(user1))
+            new_port = input("port:(若默认{}请回车键跳过)".format(port1))
+            new_pwd = input("pwd:(若默认{}请回车键跳过)".format(pwd1))
+            new_tbj_pem = input("tbj_pem:(若默认{}请回车键跳过)".format(tbj_pem1))
+            server_dict[conf_sname] = {"host": host, "user": new_user, "port": new_port, "pwd": new_pwd,
+                                       "pem": new_tbj_pem}
+        new_server_conf_str = '''
+        user = "{}"  # 用户名
+        port = "{}"  # 端口号
+        pwd = "{}"  # 普通密码
+        root_pwd = "{}"  # root 密码
+        tbj_pem = "{}"  # 跳板机序号\n\nserver_dict = {}'''.format(user1, port1, pwd1, root_pwd1, tbj_pem1,
+                                                              str(server_dict)).replace(" " * 8, "").replace("},",
+                                                                                                             "},\n")
+        with open("{}/conf.py".format(file_path), 'w') as f:
+            f.write(new_server_conf_str)
+
+    except IndexError:
+        print("执行命令为: alters 服务器名称 (sname|host|user|port|pwd) 具体的值  alters 服务器名称")
+
 
 if __name__ == '__main__':
     main()
